<?php
/**
 * Verity Pro functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Verity Pro
 */

if ( ! function_exists( 'verity_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function verity_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Verity Pro, use a find and replace
		 * to change 'verity-pro' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'verity-pro', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		set_post_thumbnail_size( 1332, 666, true );

		add_image_size( 'verity-first-image', 666, 666, true );
		add_image_size( 'verity-featured-archive-image', 444, 444, true );
		add_image_size( 'verity-hero-image', 488, 528, true );
		add_image_size( 'verity-thumbnail-avatar', 90, 90, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1'      => esc_html__( 'Primary', 'verity-pro' ),
			'social-menu' => esc_html__( 'Social Menu', 'verity-pro' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'verity_custom_background_args', array(
			'default-color' => 'f2f2f2',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add theme support for Custom Logo
		add_theme_support( 'custom-logo', array(
			'height'     => 100,
			'width'      => 100,
			'flex-width' => true,
		) );

		/**
		 * Theme Palace Auto Updater
		 */
		$update_notifier = get_theme_mod( 'verity_update_notifier' );

		if ( ! $update_notifier ) {
			require trailingslashit( get_template_directory() ) . '/updater/theme-updater.php';
		}
	}
endif;
add_action( 'after_setup_theme', 'verity_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function verity_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'verity_content_width', 792 );
}
add_action( 'after_setup_theme', 'verity_content_width', 0 );

if ( ! function_exists( 'verity_template_redirect' ) ) :
	/**
	 * Set the content width in pixels, based on the theme's design and stylesheet for different value other than the default one
	 *
	 * @global int $content_width
	 */
	function verity_template_redirect() {
		if ( is_page_template( 'templates/full-width-page.php' ) ){
			$GLOBALS['content_width'] = 1238;
			return;
		} elseif ( is_page_template( 'templates/no-sidebar.php' ) || is_page_template( 'templates/left-sidebar.php' ) || is_page_template( 'templates/right-sidebar.php' ) ) {
			// Do not change content width if using any other page template than full-width-page.php
			return;
		}

		$layout = get_theme_mod( 'verity_default_layout' );

		if ( 'no-sidebar-full-width' === $layout ) {
			$GLOBALS['content_width'] = 1238;
		}
	}
endif;
add_action( 'template_redirect', 'verity_template_redirect' );

/**
 * Count the number of footer sidebars to enable dynamic classes for the footer
 *
 * @since Verity Pro 1.0
 */
function verity_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'sidebar-2' ) ) {
		$count++;
	}

	if ( is_active_sidebar( 'sidebar-3' ) ) {
		$count++;
	}

	if ( is_active_sidebar( 'sidebar-4' ) ) {
		$count++;
	}

	if ( is_active_sidebar( 'sidebar-5' ) ) {
		$count++;
	}

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
		case '4':
			$class = 'four';
			break;
	}

	if ( $class )
		echo 'class="widget-area footer-widget-area ' . $class . '"';
}


if ( ! function_exists( 'verity_fonts_url' ) ) :
/**
 * Register Google fonts for Verity Pro.
 *
 * Create your own verity_fonts_url() function to override in a child theme.
 *
 * @since Verity Pro 1.0
 *
 * @return string Google fonts URL for the theme.
 */
function verity_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	$font_values   = array();
	$font_values[] = get_theme_mod( 'verity_body_font', 'lato' );
	$font_values[] = get_theme_mod( 'verity_title_font', 'playfair-display' );
	$font_values[] = get_theme_mod( 'verity_tagline_font', 'lato' );
	$font_values[] = get_theme_mod( 'verity_content_title_font', 'lato' );
	$font_values[] = get_theme_mod( 'verity_content_font', 'lato' );
	$font_values[] = get_theme_mod( 'verity_headings_font', 'lato' );
	$font_values[] = 'amatic-sc'; // This needs to be loaded irrespective of the value chosen in options

	$web_fonts = array(
		'allan'             => 'Allan',
		'allerta'           => 'Allerta',
		'amaranth'          => 'Amaranth',
		'amatic-sc'         => 'Amatic SC',
		'bitter'            => 'Bitter',
		'cabin'             => 'Cabin',
		'cantarell'         => 'Cantarell',
		'crimson-text'      => 'Crimson+Text',
		'cuprum'            => 'Cuprum',
		'dancing-script'    => 'Dancing Script',
		'droid-sans'        => 'Droid Sans',
		'droid-serif'       => 'Droid Serif',
		'exo'               => 'Exo',
		'exo-2'             => 'Exo 2',
		'istok-web'         => 'Istok Web',
		'josefin-sans'      => 'Josefin Sans',
		'lato'              => 'Lato',
		'lobster'           => 'Lobster',
		'lora'              => 'Lora',
		'montserrat'        => 'Montserrat',
		'nobile'            => 'Nobile',
		'noto-serif'        => 'Noto Serif',
		'neuton'            => 'Neuton',
		'open-sans'         => 'Open Sans',
		'oswald'            => 'Oswald',
		'patua-one'         => 'Patua One',
		'playfair-display'  => 'Playfair Display',
		'pt-sans'           => 'PT Sans',
		'pt-serif'          => 'PT Serif',
		'rubik'             => 'Rubik',
		'quattrocento-sans' => 'Quattrocento Sans',
		'roboto'            => 'Roboto',
		'roboto-slab'       => 'Roboto Slab',
		'source-sans-pro'   => 'Source Sans Pro',
		'ubuntu'            => 'Ubuntu',
		'varela'            => 'Varela',
		'yanone-kaffeesatz' => 'Yanone Kaffeesatz',
	);

	$font_values = array_unique( $font_values ); // Make the array of fonts unique so that same font is not loaded twice.

	$font_values = array_intersect( $font_values, array_keys( $web_fonts ) ); // Intersect selected fonts and webfonts to only recover fonts that need loading.

	foreach ( $font_values as $font_value ) {
		$fonts[] = $web_fonts[ $font_value ] . ':400,700,900,400italic,700italic,900italic';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return esc_url( $fonts_url );
}
endif;

/**
 * Enqueue scripts and styles.
 */
function verity_scripts() {

	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'verity-fonts', verity_fonts_url(), array(), null );

	// Theme stylesheet.
	wp_enqueue_style( 'verity-style', get_stylesheet_uri() );

	// Load the html5 shiv.
	wp_enqueue_script( 'verity-html5', get_template_directory_uri() . '/assets/js/html5.min.js', array(), '3.7.3' );
	wp_script_add_data( 'verity-html5', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'verity-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.min.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'verity-keyboard-image-navigation', get_template_directory_uri() . '/assets/js/keyboard-image-navigation.min.js', array( 'jquery' ), '20160816' );
	}

	wp_register_script( 'jquery-match-height', get_template_directory_uri() . '/assets/js/jquery.matchHeight.min.js', array( 'jquery' ), '20151215', true );

	wp_enqueue_script( 'verity-script', get_template_directory_uri() . '/assets/js/functions.min.js', array( 'jquery', 'jquery-match-height' ), '20150507', true );

	wp_localize_script( 'verity-script', 'verityScreenReaderText', array(
		'expand'   => esc_html__( 'expand child menu', 'verity-pro' ),
		'collapse' => esc_html__( 'collapse child menu', 'verity-pro' ),
		'icon'     => verity_get_svg( array( 'icon' => 'angle-down', 'fallback' => true ) ),
	) );

	$font_family_css = verity_get_font_family_css();

	if ( '' !== $font_family_css ) {
		wp_add_inline_style( 'verity-style', $font_family_css );
	}

	//Slider Scripts
	if( 'disabled' !== get_theme_mod( 'verity_slider_option', 'disabled' ) ) {
		wp_enqueue_script( 'jquery-cycle2', get_template_directory_uri() . '/assets/js/jquery.cycle/jquery.cycle2.min.js', array( 'jquery' ), '2.1.5', true );

		$transition_effects = array(
			get_theme_mod( 'verity_slider_transition_effects', 'fade' ),
		);

		/**
		 * Condition checks for additional slider transition plugins
		 */
		// Scroll Vertical transition plugin addition.
		if ( in_array( 'scrollVert', $transition_effects ) ){
			wp_enqueue_script( 'jquery-cycle2-scrollVert', get_template_directory_uri() . '/assets/js/jquery.cycle/jquery.cycle2.scrollVert.min.js', array( 'jquery-cycle2' ), '2.1.5', true );
		}

		// Flip transition plugin addition.
		if ( in_array( 'flipHorz', $transition_effects ) || in_array( 'flipVert', $transition_effects ) ){
			wp_enqueue_script( 'jquery-cycle2-flip', get_template_directory_uri() . '/assets/js/jquery.cycle/jquery.cycle2.flip.min.js', array( 'jquery-cycle2' ), '2.1.5', true );
		}

		// Shuffle transition plugin addition.
		if ( in_array( 'tileSlide', $transition_effects ) || in_array( 'tileBlind', $transition_effects ) ){
			wp_enqueue_script( 'jquery-cycle2-tile', get_template_directory_uri() . '/assets/js/jquery.cycle/jquery.cycle2.tile.min.js', array( 'jquery-cycle2' ), '2.1.5', true );
		}

		// Shuffle transition plugin addition.
		if ( in_array( 'shuffle', $transition_effects ) ){
			wp_enqueue_script( 'jquery-cycle2-shuffle', get_template_directory_uri() . '/assets/js/jquery.cycle/jquery.cycle2.shuffle.min.js', array( 'jquery-cycle2' ), '2.1.5', true );
		}
	}

	// Enqueue fitvid if JetPack is not installed.
	if ( ! class_exists( 'Jetpack' ) ) {
		wp_enqueue_script( 'jquery-fitvids', get_template_directory_uri() . '/assets/js/fitvids.min.js', array( 'jquery' ), '1.1', true );
	}

}
add_action( 'wp_enqueue_scripts', 'verity_scripts' );

/**
 * Checks if there are options already present from Verity free version and adds it to the Verity Pro theme options
 *
 * @since Verity Pro 1.2
 * @hook after_theme_switch
 */
function verity_setup_options() {
	// Perform action only if theme_mods_theme_mods_verity-pro does not exist.
	if( ! get_option( 'theme_mods_verity-pro' ) ) {
		// Perform action only if theme_mods_verity free version exists.
		if ( $free_options = get_option ( 'theme_mods_verity' ) ) {
			update_option('theme_mods_verity-pro', $free_options );
		}
	}
}
add_action( 'after_switch_theme', 'verity_setup_options' );

/**
 * Implement the Custom Header feature.
 */
require get_parent_theme_file_path( '/inc/custom-header.php' );

/**
 * Custom template tags for this theme.
 */
require get_parent_theme_file_path( '/inc/template-tags.php' );

/**
 * Custom functions that act independently of the theme templates.
 */
require get_parent_theme_file_path( '/inc/extras.php' );

/**
 * Customizer additions.
 */
require get_parent_theme_file_path( '/inc/customizer/customizer.php' );

/**
 * Load Jetpack compatibility file.
 */
require get_parent_theme_file_path( '/inc/jetpack.php' );

/**
 * SVG icons functions and filters.
 */
require get_parent_theme_file_path( '/inc/icon-functions.php' );

/**
 * Include Breadcrumb
 */
require get_parent_theme_file_path( '/inc/breadcrumb.php' );

/**
 * Include Slider
 */
require get_parent_theme_file_path( '/inc/featured-slider.php' );

/**
 * Include Widgets
 */
require get_parent_theme_file_path( '/inc/widgets/widgets.php' );

/**
 * Include WooCommerce Support
 */
require get_parent_theme_file_path( '/inc/woocommerce.php' );
