<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Verity Pro
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function verity_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	if ( is_singular() ) {
		$classes[] = 'singular';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	if ( has_custom_header() && is_front_page() ) {
		$classes[] = 'absolute-header';
	} else {
		if ( is_post_type_archive( 'jetpack-testimonial' ) ) {
			$jetpack_options = get_theme_mod( 'jetpack_testimonials' );

			if ( isset( $jetpack_options['featured-image'] ) && '' !== $jetpack_options['featured-image'] ) {
				$classes[] = 'has-custom-header';
			}
		} elseif ( is_post_type_archive( 'jetpack-portfolio' ) ) {
			$jetpack_portfolio_featured_image = get_option( 'jetpack_portfolio_featured_image' );

			if ( '' !== $jetpack_portfolio_featured_image ) {
				$classes[] = 'has-custom-header';
			}
		} elseif ( verity_jetpack_featured_image_display() ) {
			$classes[] = 'has-custom-header';
		}
	}

	// Adds a class of navigation-(default|classic) to blogs.
	if ( 'classic' === get_theme_mod( 'verity_menu_type' ) ) {
		$classes[] = 'navigation-classic';
	} else {
		$classes[] = 'navigation-default';
	}

	// Adds a class of (full-width|box) to blogs.
	if ( 'full-width' === get_theme_mod( 'verity_layout_type' ) ) {
		$classes[] = 'full-width-layout';
	} else {
		$classes[] = 'boxed-layout';
	}

	// Adds a class with respect to layout selected.
	if ( is_singular() || ( class_exists( 'woocommerce' ) && is_shop() ) ) {
		$layout  = verity_get_theme_layout();
		$sidebar = verity_get_sidebar_id();

		if ( 'no-sidebar-full-width' === $layout ) {
			$classes[] = 'no-sidebar full-width';
		} elseif ( 'left-sidebar' === $layout ) {
			if ( '' !== $sidebar ) {
				$classes[] = 'two-columns content-right';
			}
		} elseif ( 'right-sidebar' === $layout ) {
			if ( '' !== $sidebar ) {
				$classes[] = 'two-columns content-left';
			}
		}
	}

	return $classes;
}
add_filter( 'body_class', 'verity_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function verity_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'verity_pingback_header' );

/**
 * Checks to see if we're on the homepage or not.
 */
function verity_is_frontpage() {
	return ( is_front_page() && ! is_home() );
}

/**
 * Remove first post from blog as it is already show via recent post template
 */
function verity_alter_home( $query ) {
	if ( $query->is_home() && $query->is_main_query() ) {
		/**
		 * Remove first post from main query as it is shown in recent posts prioritizing the sticky posts
		 */
		$paged = intval( ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1 );

		if ( 1 == $paged && is_front_page() ) {
			$latest_post = get_posts( array(
					'posts_per_page' => 1,
					'post__in'       => get_option( 'sticky_posts' ),
					'paged'          => '',
				)
			);

			$query->set( 'post__not_in', array( $latest_post[0]->ID ) );
		}

		// Ignore Sticky Posts on main query.
		$query->set( 'ignore_sticky_posts', 1 );

		$cats 		= get_theme_mod( 'verity_front_page_category' );

		if ( is_array( $cats ) && ! in_array( '0', $cats ) ) {
			$query->query_vars['category__in'] = $cats;
		}
	}
}
add_action( 'pre_get_posts', 'verity_alter_home' );

/**
 * Function to add Scroll Up icon
 */
function verity_scrollup() {
	$verity_disable_scrollup = get_theme_mod( 'verity_disable_scrollup' );

	if ( $verity_disable_scrollup ) {
		return;
	}

	echo '<a href="#masthead" id="scrollup">' .verity_get_svg( array( 'icon' => 'angle-down' ) ) . '<span class="screen-reader-text">' . esc_html__( 'Scroll Up', 'verity-pro' ) . '</span></a>' ;

}
add_action( 'wp_footer', 'verity_scrollup', 1 );

/**
 * Adds font family custom CSS
 */
function verity_get_font_family_css() {
	$font_family_options = verity_font_family_options();

	$fonts = verity_avaliable_fonts();

	$css = array();

	foreach ( $font_family_options as $key => $value) {
		if ( $option = get_theme_mod( $key ) ) {
			$css[] = $value['selector'] . " { font-family: " . $fonts [ $option ]['label'] . "; }";
		}
	}

	$css = implode( "\n", $css );

	return $css;
}

function verity_get_sidebar_id() {
	$sidebar = '';

	if ( is_active_sidebar( 'sidebar-6' ) && class_exists( 'woocommerce' ) && ( is_woocommerce() || is_cart() || is_checkout() ) ) {
		$sidebar = 'sidebar-6'; // WooCommerce Sidebar
	} elseif ( is_active_sidebar( 'sidebar-optional-one' ) && 'optional-sidebar-one' == $sidebaroptions  ) {
		$sidebar = 'sidebar-optional-one';
	} elseif ( is_active_sidebar( 'sidebar-optional-two' ) && 'optional-sidebar-two' == $sidebaroptions  ) {
		$sidebar = 'sidebar-optional-two';
	} elseif ( is_active_sidebar( 'sidebar-optional-three' ) && 'optional-sidebar-three' == $sidebaroptions  ) {
		$sidebar = 'sidebar-optional-three';
	} elseif ( is_active_sidebar( 'sidebar-optional-homepage' ) && ( is_front_page() || ( is_home() && $page_id != $page_for_posts ) ) ) {
		$sidebar = 'sidebar-optional-homepage';
		} elseif ( is_active_sidebar( 'sidebar-optional-archive' ) && ( is_archive() || ( is_home() && $page_id != $page_for_posts ) ) ) {
		$sidebar = 'sidebar-optional-archive';
	} elseif ( is_page() && is_active_sidebar( 'sidebar-optional-page' ) ) {
		$sidebar = 'sidebar-optional-page';
	} elseif ( is_single() && is_active_sidebar( 'sidebar-optional-post' ) ) {
		$sidebar = 'sidebar-optional-post';
	} elseif ( is_active_sidebar( 'sidebar-1' ) ) {
		$sidebar = 'sidebar-1'; // Primary Sidebar
	}

	return $sidebar;
}

function verity_get_theme_layout() {
	$layout = '';

	if ( is_page_template( 'templates/no-sidebar.php' ) ) {
		 $layout = 'no-sidebar';
	} elseif ( is_page_template( 'templates/full-width-page.php' ) ) {
		 $layout = 'no-sidebar-full-width';
	} elseif ( is_page_template( 'templates/left-sidebar.php' ) ) {
		$layout = 'left-sidebar';
	} elseif ( is_page_template( 'templates/right-sidebar.php' ) ) {
		$layout = 'right-sidebar';
	} else {
		$layout = get_theme_mod( 'verity_default_layout', 'no-sidebar' );

		if ( class_exists( 'woocommerce' ) && ( is_shop() || is_woocommerce() || is_cart() || is_checkout() ) ) {
			$layout = get_theme_mod( 'verity_woocommerce_layout', 'no-sidebar' );
		}
	}

	return $layout;
}

if ( ! function_exists( 'verity_excerpt_length' ) ) :
	/**
	 * Sets the post excerpt length to n words.
	 *
	 * function tied to the excerpt_length filter hook.
	 * @uses filter excerpt_length
	 *
	 * @since Verity Pro 1.1
	 */
	function verity_excerpt_length( $length ) {
		if ( is_admin() ) {
			return $length;
		}

		// Getting data from Customizer Options
		$length	= get_theme_mod( 'verity_excerpt_length', 30 );
		return absint( $length );
	}
endif; //verity_excerpt_length
add_filter( 'excerpt_length', 'verity_excerpt_length' );


/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and a option from customizer.
 * @return string option from customizer prepended with an ellipsis.
 */
if ( ! function_exists( 'verity_excerpt_more' ) ) :
	function verity_excerpt_more( $more ) {
		if ( is_admin() ) {
			return $more;
		}

		$more_tag_text	= get_theme_mod( 'verity_excerpt_more_text',  esc_html__( 'Continue reading', 'verity-pro' ) );

		$link = sprintf( '<a href="%1$s" class="more-link"><span>%2$s</span></a>',
			esc_url( get_permalink( get_the_ID() ) ),
			/* translators: %s: Name of current post */
			wp_kses_data( $more_tag_text ). '<span class="screen-reader-text">' . get_the_title( get_the_ID() ) . '</span>'
			);

		return ' &hellip; ' . $link;
	}
endif;
add_filter( 'excerpt_more', 'verity_excerpt_more' );


if ( ! function_exists( 'verity_custom_excerpt' ) ) :
	/**
	 * Adds Continue reading link to more tag excerpts.
	 *
	 * function tied to the get_the_excerpt filter hook.
	 *
	 * @since Verity Pro 1.1
	 */
	function verity_custom_excerpt( $output ) {

		if ( has_excerpt() && ! is_attachment() ) {
			$more_tag_text = get_theme_mod( 'verity_excerpt_more_text', esc_html__( 'Continue reading', 'verity-pro' ) );

			$link = sprintf( '<a href="%1$s" class="more-link"><span>%2$s</span></a>',
			esc_url( get_permalink( get_the_ID() ) ),
			/* translators: %s: Name of current post */
			wp_kses_data( $more_tag_text ). '<span class="screen-reader-text">' . get_the_title( get_the_ID() ) . '</span>'
			);

			$link = ' &hellip; ' . $link;

			$output .= $link;
		}

		return $output;
	}
endif; //verity_custom_excerpt
add_filter( 'get_the_excerpt', 'verity_custom_excerpt' );


if ( ! function_exists( 'verity_more_link' ) ) :
	/**
	 * Replacing Continue reading link to the_content more.
	 *
	 * function tied to the the_content_more_link filter hook.
	 *
	 * @since Verity Pro 1.1
	 */
	function verity_more_link( $more_link, $more_link_text ) {
		$more_tag_text = get_theme_mod( 'verity_excerpt_more_text', esc_html__( 'Continue reading', 'verity-pro' ) );

		return ' &hellip; ' . str_replace( $more_link_text, $more_tag_text, $more_link );
	}
endif; //verity_more_link
add_filter( 'the_content_more_link', 'verity_more_link', 10, 2 );


if ( ! function_exists( 'verity_content_nav' ) ) :
	/**
	 * Display navigation/pagination when applicable
	 *
	 * @since Verity Pro 1.1
	 */
	function verity_content_nav() {
		global $wp_query, $post;

		// Don't print empty markup on single pages if there's nowhere to navigate.
		if ( is_single() ) {
			$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
			$next = get_adjacent_post( false, '', false );

			if ( ! $next && ! $previous )
				return;
		}

		// Don't print empty markup in archives if there's only one page.
		if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) ) {
			return;
		}

		$def_pagination = 'default';

		if ( class_exists( 'Jetpack' ) ) {
			$def_pagination = 'infinite-scroll-click';
		}

		$pagination_type = get_theme_mod( 'verity_pagination_type', $def_pagination );

		/**
		 * Check if navigation type is Jetpack Infinite Scroll and if it is enabled, else goto default pagination
		 * if it's active then disable pagination
		 */
		if ( ( 'infinite-scroll-click' == $pagination_type || 'infinite-scroll-scroll' == $pagination_type ) && class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) {
			return false;
		}

		/**
		 * Check if navigation type is numeric and if Wp-PageNavi Plugin is enabled
		 */
		if ( 'numeric' == $pagination_type && function_exists( 'the_posts_pagination' ) ) {
			// Previous/next page navigation.
			the_posts_pagination( array(
				'prev_text'          => esc_html__( 'Previous', 'verity-pro' ),
				'next_text'          => esc_html__( 'Next', 'verity-pro' ),
				'before_page_number' => '<span class="meta-nav screen-reader-text">' . esc_html__( 'Page', 'verity-pro' ) . ' </span>',
			) );
		}
		else {
			the_posts_navigation();
		}
	}
endif; // verity_content_nav


if ( ! function_exists( 'verity_rss_redirect' ) ) :
	/**
	 * Redirect WordPress Feeds To FeedBurner
	 *
	 * @action template_redirect
	 *
	 * @since Verity 1.1
	 */
	function verity_rss_redirect() {
		$feed_redirect 	= get_theme_mod( 'verity_feed_redirect' , '' );

		if ( $feed_redirect ) {
			$url = 'Location: '.$feed_redirect;
			if ( is_feed() && !preg_match('/feedburner|feedvalidator/i', $_SERVER['HTTP_USER_AGENT']))
			{
				header( esc_url( $url ) );
				header('HTTP/1.1 302 Temporary Redirect');
			}
		}
	}
endif; //verity_rss_redirect
add_action( 'template_redirect', 'verity_rss_redirect' );


/**
 * Check if a section is enabled or not based on the $value parameter
 * @param  string $value Value of the section that is to be checked
 * @return boolean return true if section is enabled otherwise false
 */
function verity_check_section( $value ) {
	global $wp_query;

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	// Front page displays in Reading Settings
	$page_for_posts = get_option('page_for_posts');

	return ( 'entire-site' == $value  || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $value ) );
}

/**
 * Return the first image in a post. Works inside a loop.
 * @param [integer] $post_id [Post or page id]
 * @param [string/array] $size Image size. Either a string keyword (thumbnail, medium, large or full) or a 2-item array representing width and height in pixels, e.g. array(32,32).
 * @param [string/array] $attr Query string or array of attributes.
 * @return [string] image html
 *
 * @since Verity Pro 1.1
 */

function verity_get_first_image( $postID, $size, $attr ) {
	ob_start();

	ob_end_clean();

	$image 	= '';

	$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', get_post_field('post_content', $postID ) , $matches);

	if( isset( $matches [1] [0] ) ) {
		//Get first image
		$first_img = $matches [1] [0];

		return '<img class="pngfix wp-post-image" src="'. esc_url( $first_img ) .'">';
	}

	return false;
}

if ( ! function_exists( 'verity_truncate_phrase' ) ) :
	/**
	 * Return a phrase shortened in length to a maximum number of characters.
	 *
	 * Result will be truncated at the last white space in the original string. In this function the word separator is a
	 * single space. Other white space characters (like newlines and tabs) are ignored.
	 *
	 * If the first `$max_characters` of the string does not contain a space character, an empty string will be returned.
	 *
	 * @since NepalBuzz 1.0
	 *
	 * @param string $text            A string to be shortened.
	 * @param integer $max_characters The maximum number of characters to return.
	 *
	 * @return string Truncated string
	 */
	function verity_truncate_phrase( $text, $max_characters ) {

		$text = trim( $text );

		if ( mb_strlen( $text ) > $max_characters ) {
			//* Truncate $text to $max_characters + 1
			$text = mb_substr( $text, 0, $max_characters + 1 );

			//* Truncate to the last space in the truncated string
			$text = trim( mb_substr( $text, 0, mb_strrpos( $text, ' ' ) ) );
		}

		return $text;
	}
endif; //verity_truncate_phrase


if ( ! function_exists( 'verity_get_the_content_limit' ) ) :
	/**
	 * Return content stripped down and limited content.
	 *
	 * Strips out tags and shortcodes, limits the output to `$max_char` characters, and appends an ellipsis and more link to the end.
	 *
	 * @since NepalBuzz 1.0
	 *
	 * @param integer $max_characters The maximum number of characters to return.
	 * @param string  $more_link_text Optional. Text of the more link. Default is "(more...)".
	 * @param bool    $stripteaser    Optional. Strip teaser content before the more text. Default is false.
	 *
	 * @return string Limited content.
	 */
	function verity_get_the_content_limit( $max_characters, $more_link_text = '(more...)', $stripteaser = false ) {

		$content = get_the_content( '', $stripteaser );

		//* Strip tags and shortcodes so the content truncation count is done correctly
		$content = strip_tags( strip_shortcodes( $content ), apply_filters( 'get_the_content_limit_allowedtags', '<script>,<style>' ) );

		//* Remove inline styles / scripts
		$content = trim( preg_replace( '#<(s(cript|tyle)).*?</\1>#si', '', $content ) );

		//* Truncate $content to $max_char
		$content = verity_truncate_phrase( $content, $max_characters );

		//* More link?
		if ( $more_link_text ) {
			$link   = apply_filters( 'get_the_content_more_link', sprintf( '<span class="more-button"><a href="%s" class="more-link">%s</a></span>', esc_url( get_permalink() ), $more_link_text ), $more_link_text );
			$output = sprintf( '<p>%s %s</p>', $content, $link );
		} else {
			$output = sprintf( '<p>%s</p>', $content );
			$link = '';
		}

		return apply_filters( 'verity_get_the_content_limit', $output, $content, $link, $max_characters );

	}
endif; //verity_get_the_content_limit
